package com.gic.operation.web.controller;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.constant.UserConstants;
import com.gic.auth.dto.UserDTO;
import com.gic.auth.exception.StoreException;
import com.gic.auth.service.UserApiService;
import com.gic.auth.utils.CreatePasswordAutoUtil;
import com.gic.commons.util.Md5Util;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.dto.EnterpriseDTO;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseRestResponse;
import com.gic.enterprise.service.EnterpriseApiService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author guojx
 * @date 2019/7/17 10:32 AM
 */
@RestController
@RequestMapping("/enterprise")
public class EnterpriseController {
    private static final Logger LOGGER = LoggerFactory.getLogger(EnterpriseController.class);
    @Autowired
    private EnterpriseApiService enterpriseApiService;
    @Autowired
    private UserApiService userApiService;

    @RequestMapping("/save-enterprise")
    @Transactional(rollbackFor = Exception.class)
    public RestResponse saveEnterprise(@Validated({EnterpriseDTO.SaveEnterpriseValid.class}) EnterpriseDTO enterpriseDTO,
                                       @Validated({UserDTO.SaveUserValid.class}) UserDTO userDTO) {
        ServiceResponse<Integer> enterpriseResult = enterpriseApiService.saveEnterprise(enterpriseDTO);
        if (enterpriseResult.isSuccess()) {
            int enterpriseId = enterpriseResult.getResult();
            userDTO.setEnterpriseId(enterpriseId);
            int passwordType = userDTO.getPasswordType();
            //加密
            if (UserConstants.CREATE_AUTO == passwordType) {
                //自动随机生成
               userDTO.setPassword(encryptPassword(CreatePasswordAutoUtil.getStringRandom(8)));
            } else {
                if (userDTO.getPassword().equals(userDTO.getConfirmPassword())) {
                    //如果一致
                    userDTO.setPassword(encryptPassword(userDTO.getPassword()));
                } else {
                    RestResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "密码不一致");
                }
            }
            //新增
            ServiceResponse userResult = userApiService.saveUser(userDTO);
            if (userResult.isSuccess()) {
                return RestResponse.success();
            } else {
                //回滚
                throw new StoreException(userResult.getCode(), userResult.getMessage());
            }
        } else {
            return EnterpriseRestResponse.failure(enterpriseResult);
        }
    }

    private static String encryptPassword(String password) {
        Md5Util md5 = new Md5Util();
        return md5.encrypt(password + password);
    }
}
